// ----------------------------------------------------------------------------
// VFIS 
// ----------------------------------------------------------------------------
// Verified Fredholm Integral Equation Solver
// for linear Fredholm Integral Equations of the second kind
// (Serial System Version)
// ----------------------------------------------------------------------------
// Verifizierter Integralgleichungsloeser 
// fuer lineare Fredholmsche Integralgleichungen zweiter Art
// (Serielle Systemversion)
// ----------------------------------------------------------------------------
// Copyright (c) 2004-2007 Markus Grimmer
//
// markus.grimmer@math.uni-wuppertal.de
// ----------------------------------------------------------------------------

// This file is part of the Verified Fredholm Integral Equation Solver VFIS.
// 
// VFIS is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// VFIS is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with VFIS; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------
// ----------------------------------------------------------------------------

/**
 * @file System-FIGL-Loeser-Bsp.cpp
 * Example Application file for VFIS Integral Equation Solver.
 */

#include "interval.hpp"
#include "itaylor.hpp"     
#include "dim2taylor.hpp"  

#include <fstream>

#include "System-FIGL-Loeser.hpp"

using namespace std;
using namespace cxsc;
using namespace taylor;

/**
 * Kernel function of the integral equation.
 * @param x A dim2taylor_vector with the two variables as dim2taylor arguments
 * @return The resulting dim2taylor object
 */
dim2taylor K(dim2taylor_vector& x)
{
  dim2taylor s=x[1];
  dim2taylor t=x[2];
  dim2taylor erg;

  erg=s*sqr(t)-sqr(s)*t;

  return erg;
}
// dim2taylor K(dim2taylor_vector& x)
// {
// 	return (x[1]+1)*exp(-x[1]*x[2])/real(2.0); 
// }

/**
 * Right hand side of the integral equation.
 * @param s The function variable as itaylor argument
 * @return The resulting itaylor object
 */
itaylor RS(itaylor& s)
{
  return (s-real(0.5)) * erf(sin(real(9.0)*s));
}
// itaylor RS(itaylor& s)
// {
// 	return exp(-s)-real(0.5)+real(0.5)*exp(-s-1);
// }

/**
 * Domain of the first kernel variable.
 */
const interval KDefS=interval(0.0,1.0);

/**
 * Domain of the second kernel variable.
 */
const interval KDefT=interval(0.0,1.0);

/**
 * Domain of the right hand side (should be identical with first kernel variable).
 */
const interval RSDef=interval(0.0,1.0);

/**
 * Main function of the application.
 */
int main()
{
  // Taylor and system orders
  int ord=6;
  int sysord=32; 
  
  // Output file
  ofstream outf("Bsp-T6-N32.out");
  
  // Define Integral Equation
  IntegralGleichungsSystem IGLSys(K,KDefS,KDefT,RS,RSDef,sysord,ord,outf);  
  
  // Solve
  IGLSys.Einschliessung_berechnen(outf);
  
  // Export
  IGLSys.Export_Plot("Maple", "Bsp-T6-N32.plot.mpl", 40);

  return 0;
}
